@@ -1,6 +1,6 @@
 package HTML::SearchPage::Param;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # $Id: Param.pm,v 1.8 2007/09/19 21:30:18 canaran Exp $
 
@@ -306,13 +306,13 @@ get/set after object instantiation.
 
 =head1 AUTHOR
 
-Payan Canaran <canaran@cshl.edu>
+Payan Canaran <pcanaran@cpan.org>
 
 =head1 BUGS
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 ACKNOWLEDGEMENTS
 
